@@ -3,7 +3,8 @@
 ## =============================
 
 plot.stslist.modst <- function(x, cpal = NULL, ylab = NULL, yaxis = TRUE,
-  xaxis = TRUE, xtlab = NULL, xtstep = NULL, cex.axis = 1,  cex.plot, ...) {
+  xaxis = TRUE, xtlab = NULL, xtstep = NULL, tick.last = NULL,
+  cex.axis = 1, cex.plot, ...) {
 
   TraMineR.check.depr.args(alist(cex.axis = cex.plot))
 
@@ -32,6 +33,9 @@ plot.stslist.modst <- function(x, cpal = NULL, ylab = NULL, yaxis = TRUE,
 		## For sequence objects created with previous versions
 		else {xtstep <- 1}
 	}
+	if(is.null(tick.last)){
+		tick.last <- ifelse(!is.null(attr(x, "tick.last")), attr(x, "tick.last"), FALSE)
+	}
 
 	if (is.null(ylab)) ylab <- paste("State freq. (",wlab,"n=",round(n,2),")",sep="")
 
@@ -70,6 +74,7 @@ plot.stslist.modst <- function(x, cpal = NULL, ylab = NULL, yaxis = TRUE,
 	## Plotting the x axis
 	if (xaxis) {
 		tpos <- seq(1,seql, xtstep)
+    if (tick.last & tpos[length(tpos)] < seql) tpos <- c(tpos,seql)
 		axis(1, at=tpos-0.5, labels=xtlab[tpos], pos=-0.02,
 		# mgp=c(3,0.5,0),
 		cex.axis=cex.axis)
